@@ -2,7 +2,7 @@ tSIRRotate <-
   function(x, y, h, ...){
     r <- length(dim(x)) - 1
     
-    rotateStack <- list()
+    rotateStack <- vector("list", r)
     for(m in 1:r){
       rotateStack[[m]] <- t(eigenVectors(mModeTSIRMatrix(x, m, y, h, ...)))
     }
